@@ -6,9 +6,26 @@ import time
 
 from dbt.adapters.factory import get_adapter
 
-DBT_CONFIG_DIR = os.path.expanduser(os.environ.get("DBT_CONFIG_DIR", '/root/.dbt'))
+from dbt.logger import GLOBAL_LOGGER as logger
+
+
+DBT_CONFIG_DIR = os.path.abspath(
+    os.path.expanduser(os.environ.get("DBT_CONFIG_DIR", '/root/.dbt'))
+)
+
 DBT_PROFILES = os.path.join(DBT_CONFIG_DIR, 'profiles.yml')
 
+
+class FakeArgs(object):
+    def __init__(self):
+        self.threads = 1
+        self.data = False
+        self.schema = True
+        self.full_refresh = False
+        self.models = None
+        self.exclude = None
+
+
 class DBTIntegrationTest(unittest.TestCase):
 
     def postgres_profile(self):
@@ -20,7 +37,7 @@ class DBTIntegrationTest(unittest.TestCase):
                 'outputs': {
                     'default2': {
                         'type': 'postgres',
-                        'threads': 1,
+                        'threads': 4,
                         'host': 'database',
                         'port': 5432,
                         'user': 'root',
@@ -30,7 +47,7 @@ class DBTIntegrationTest(unittest.TestCase):
                     },
                     'noaccess': {
                         'type': 'postgres',
-                        'threads': 1,
+                        'threads': 4,
                         'host': 'database',
                         'port': 5432,
                         'user': 'noaccess',
@@ -52,7 +69,7 @@ class DBTIntegrationTest(unittest.TestCase):
                 'outputs': {
                     'default2': {
                         'type': 'snowflake',
-                        'threads': 1,
+                        'threads': 4,
                         'account': os.getenv('SNOWFLAKE_TEST_ACCOUNT'),
                         'user': os.getenv('SNOWFLAKE_TEST_USER'),
                         'password': os.getenv('SNOWFLAKE_TEST_PASSWORD'),
@@ -62,7 +79,7 @@ class DBTIntegrationTest(unittest.TestCase):
                     },
                     'noaccess': {
                         'type': 'snowflake',
-                        'threads': 1,
+                        'threads': 4,
                         'account': os.getenv('SNOWFLAKE_TEST_ACCOUNT'),
                         'user': 'noaccess',
                         'password': 'password',
@@ -123,7 +140,7 @@ class DBTIntegrationTest(unittest.TestCase):
 
         # it's important to use a different connection handle here so
         # we don't look into an incomplete transaction
-        connection = adapter.acquire_connection(profile)
+        connection = adapter.acquire_connection(profile, '__test')
         self.handle = connection.get('handle')
         self.adapter_type = profile.get('type')
 
@@ -165,7 +182,7 @@ class DBTIntegrationTest(unittest.TestCase):
 
         # it's important to use a different connection handle here so
         # we don't look into an incomplete transaction
-        connection = adapter.acquire_connection(profile)
+        connection = adapter.acquire_connection(profile, '__test')
         self.handle = connection.get('handle')
         self.adapter_type = profile.get('type')
 
@@ -183,6 +200,8 @@ class DBTIntegrationTest(unittest.TestCase):
         except:
             os.rename("dbt_modules", "dbt_modules-{}".format(time.time()))
 
+        self.handle.close()
+
     @property
     def project_config(self):
         return {}
@@ -197,6 +216,8 @@ class DBTIntegrationTest(unittest.TestCase):
 
         args = ["--strict"] + args
 
+        logger.info("Invoking dbt with {}".format(args))
+
         return dbt.handle(args)
 
     def run_sql_file(self, path):
@@ -309,6 +330,21 @@ class DBTIntegrationTest(unittest.TestCase):
             )
         )
 
+    def assertTableDoesNotExist(self, table):
+        columns = self.get_table_columns(table)
+
+        self.assertEquals(
+            len(columns),
+            0
+        )
+
+    def assertTableDoesExist(self, table):
+        columns = self.get_table_columns(table)
+
+        self.assertGreater(
+            len(columns),
+            0
+        )
 
     def assertTableColumnsEqual(self, table_a, table_b):
         table_a_result = self.get_table_columns(table_a)
